@@ -2,6 +2,7 @@ import os
 import json
 from decimal import Decimal
 import pydash
+from pydash import get
 from aws_lambda_stream.utils.dynamodb import unmarshall,marshall
 
 
@@ -49,6 +50,8 @@ def from_dynamodb(
                         'timestamp': _get_timestamp(uow)
                     },
                 }
+            ).sort_by(
+                lambda uow: pydash.get(uow, 'event.timestamp', 0)
             ).value()
 
 def _calculate_event_type_prefix(record, opt):
@@ -69,17 +72,20 @@ def _calculate_event_type_suffix(record):
         old_image = record.get('dynamodb').get('OldImage')
         if ((new_image and new_image.get('deleted')) or
             (old_image and old_image.get('deleted'))):
-            if new_image and new_image.get('deleted'):
+            if new_image and get(new_image, 'deleted.BOOL'):
                 return 'deleted'
-            if old_image and old_image.get('deleted'):
+            if old_image and get(old_image, 'deleted.BOOL'):
                 return 'undeleted'
     return suffix
 
 
 def _get_timestamp(uow):
     _new = uow['event']['raw']['new']
-    if 'timestamp' in _new:
+    _old = uow['event']['raw']['old']
+    if _new and 'timestamp' in _new:
         return _new['timestamp']
+    if _old and 'timestamp' in _old:
+        return _old['timestamp']
     return int(uow['event']['timestamp'])
 
 def _out_replicas(record):
